pub async fn deploy_prop_system<W>(
wallet: &W,
config: &PropDeployConfig,
) -> Result<PropDeployment<W>>Expand description
Deploy the independent prop-account system.
This is additive to the existing exchange deployment: callers can choose when to deploy the direct account oracle, mock price feed, proxied registry, and proxied margin pool.